"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AnimatedGradient = void 0;
var _reactNative = require("react-native");
var _react = require("react");
var _LinearGradient = require("./LinearGradient.js");
var _jsxRuntime = require("react/jsx-runtime");
// const AnimatedLinearGradient = Animated.createAnimatedComponent(LinearGradient);

const interpolate = (animatedColor, customColors, preferColors, index) => {
  return animatedColor.interpolate({
    inputRange: Array.from({
      length: customColors.length + 1
    }, (_, k) => k),
    outputRange: preferColors[index] ?? []
  });
};
const AnimatedGradient = props => {
  const color0 = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  const color1 = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  (0, _react.useEffect)(() => {
    const {
      customColors,
      speed
    } = props;
    [color0, color1].forEach(color => color.setValue(0));
    const animation = _reactNative.Animated.loop(_reactNative.Animated.parallel([color0, color1].map(animatedColor => {
      return _reactNative.Animated.timing(animatedColor, {
        toValue: customColors.length,
        duration: customColors.length * speed,
        easing: _reactNative.Easing.linear,
        useNativeDriver: props.useNativeDriver ?? true
      });
    })));
    animation.start();
    return () => animation.stop();
  }, []);
  const {
    customColors,
    children,
    start,
    end,
    style
  } = props;
  const preferColors = [];
  while (preferColors.length < 2) {
    preferColors.push(customColors.slice(preferColors.length).concat(customColors.slice(0, preferColors.length + 1)));
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_LinearGradient.LinearGradient, {
    gradientStyle: style,
    start: start,
    end: end,
    color0: interpolate(color0, customColors, preferColors, 0),
    color1: interpolate(color1, customColors, preferColors, 1),
    children: children
  });
};
exports.AnimatedGradient = AnimatedGradient;
//# sourceMappingURL=AnimatedGradient.js.map