"use strict";

import { Animated, Easing } from 'react-native';
import { useEffect, useRef } from 'react';
import { LinearGradient } from "./LinearGradient.js";

// const AnimatedLinearGradient = Animated.createAnimatedComponent(LinearGradient);
import { jsx as _jsx } from "react/jsx-runtime";
const interpolate = (animatedColor, customColors, preferColors, index) => {
  return animatedColor.interpolate({
    inputRange: Array.from({
      length: customColors.length + 1
    }, (_, k) => k),
    outputRange: preferColors[index] ?? []
  });
};
export const AnimatedGradient = props => {
  const color0 = useRef(new Animated.Value(0)).current;
  const color1 = useRef(new Animated.Value(0)).current;
  useEffect(() => {
    const {
      customColors,
      speed
    } = props;
    [color0, color1].forEach(color => color.setValue(0));
    const animation = Animated.loop(Animated.parallel([color0, color1].map(animatedColor => {
      return Animated.timing(animatedColor, {
        toValue: customColors.length,
        duration: customColors.length * speed,
        easing: Easing.linear,
        useNativeDriver: props.useNativeDriver ?? true
      });
    })));
    animation.start();
    return () => animation.stop();
  }, []);
  const {
    customColors,
    children,
    start,
    end,
    style
  } = props;
  const preferColors = [];
  while (preferColors.length < 2) {
    preferColors.push(customColors.slice(preferColors.length).concat(customColors.slice(0, preferColors.length + 1)));
  }
  return /*#__PURE__*/_jsx(LinearGradient, {
    gradientStyle: style,
    start: start,
    end: end,
    color0: interpolate(color0, customColors, preferColors, 0),
    color1: interpolate(color1, customColors, preferColors, 1),
    children: children
  });
};
//# sourceMappingURL=AnimatedGradient.js.map